Introduction
============
Thank you for to interest in contributing to pyHaFAS. In general, we manage the project via the GitHub `issues page <https://github.com/n0emis/pyhafas/issues>`_.
When you are interested in one of these issues, please write a comment, and then we eagerly await your pull request.
In special we are happy if you help us with the issues having the `help wanted <https://github.com/n0emis/pyhafas/issues?q=is%3Aopen+is%3Aissue+label%3A%22help+wanted%22>`_ label.

We want to give you an easy start with coding on pyHaFAS, so please read the pages in the category "for developers".

Most of pyHaFAS code is documented with docstrings in the code directly. Most of these docstrings are also rendered in this HTML docs on the page :doc:`/development/api`.

If you need help you can always write to us. Good ways for that are on the GitHub Issue or if the question is general, join our matrix-room `#pyhafas:matrix.org <https://matrix.to/#/#pyhafas:matrix.org>`_

Testing
-------
Before you submit your pull request please run the tests. They are also automatically run when you create the pull request.
You can execute the tests with the following command in the root directory of the project:

.. code:: console

    $ pytest
